# Pharmacelera util scripts to run and controll an experiment

## Production install

pip install pharmacelera-utils

## Local install

to be able to test the `pharmacelera-utils` package in local environment:

```bash

cd pharmaceleraModule
pip install -e .

```

This will use source code of the package from folder and install it as a library.
